/*
 * This file is part of essential.
 *
 *     essential is free software: you can redistribute it and/or modify
 *     it under the terms of the GNU General Public License as published by
 *     the Free Software Foundation, either version 3 of the License, or
 *     (at your option) any later version.
 *
 *     essential is distributed in the hope that it will be useful,
 *     but WITHOUT ANY WARRANTY; without even the implied warranty of
 *     MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 *     GNU General Public License for more details.
 *
 *     You should have received a copy of the GNU General Public License
 *     along with essential.  If not, see <http://www.gnu.org/licenses/>.
 */

package net.craftforge.commons.collections;

import java.util.HashMap;
import java.util.List;
import java.util.Map;

/**
 * Collection utils provide algorithms for standard collection operations.
 *
 * @author Christian Bick
 * @since 08.11.11
 */
public class CollectionsUtils {

    /**
     * Builds a map with the values as String arrays of a key array and a value array.
     *
     * @param keys The map keys
     * @param values The map values
     * @return The map
     */
    public static Map<String, String[]> buildMapFromArrays(String[] keys, String[] values) {
        if (keys.length != values.length) {
            throw new RuntimeException("Key array and value array are of different size");
        }
        Map<String, String[]> map = new HashMap<String, String[]>();
        for (int i=0; i < keys.length; i++) {
            map.put(keys[i], new String[] { values[i] } );
        }
        return map;
    }

    /**
     * Builds a unique key for a list of classes.
     *
     * @param classList The class list
     * @return The unique key
     */
    public static String buildKeyFromClassList(List<Class<?>> classList) {
        if (classList.isEmpty()) {
            throw new RuntimeException("Class list must not be empty");
        }
        StringBuilder builder = new StringBuilder();
        builder.append("|");
        for (Class<?> clazz : classList) {
            builder.append(clazz.getName());
            builder.append("|");
        }
        return builder.toString();
    }
}
