/*
 * This file is part of essential.
 *
 *     essential is free software: you can redistribute it and/or modify
 *     it under the terms of the GNU General Public License as published by
 *     the Free Software Foundation, either version 3 of the License, or
 *     (at your option) any later version.
 *
 *     essential is distributed in the hope that it will be useful,
 *     but WITHOUT ANY WARRANTY; without even the implied warranty of
 *     MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 *     GNU General Public License for more details.
 *
 *     You should have received a copy of the GNU General Public License
 *     along with essential.  If not, see <http://www.gnu.org/licenses/>.
 */

package net.craftforge.essential.core.resolvers;

import net.craftforge.commons.io.StreamUtils;
import net.craftforge.essential.supply.Consumer;
import net.craftforge.essential.supply.exceptions.BadInputException;

import javax.inject.Inject;
import java.io.ByteArrayInputStream;
import java.io.InputStream;
import java.io.InputStreamReader;
import java.io.UnsupportedEncodingException;

/**
 * {@inheritDoc}
 *
 * @author Christian Bick
 * @since 19.11.11
 */
public class DefaultBodyResolver implements BodyResolver {

    private InputStream bodyInputStream;

    @Inject
    public DefaultBodyResolver(InputStream inputStream) {
        this.bodyInputStream = inputStream;
    }

    /**
     * {@inheritDoc}
     */
    public InputStream getBodyInputStream() {
        return bodyInputStream;
    }

    /**
     * {@inheritDoc}
     */
    public String getBody(String charset) throws BadInputException, UnsupportedEncodingException {
        String bodyAsString = StreamUtils.readStringFromInputStream(bodyInputStream, charset);
        bodyInputStream = new ByteArrayInputStream(bodyAsString.getBytes());
        return bodyAsString;
    }

    /**
     * {@inheritDoc}
     */
    public Object getBodyAsObject(Consumer consumer, Class<?> clazz, String charset) throws BadInputException, UnsupportedEncodingException {
        InputStreamReader reader = new InputStreamReader(bodyInputStream, charset);
        return consumer.consume(clazz, reader);
    }
}
