/*
 * This file is part of essential.
 *
 *     essential is free software: you can redistribute it and/or modify
 *     it under the terms of the GNU General Public License as published by
 *     the Free Software Foundation, either version 3 of the License, or
 *     (at your option) any later version.
 *
 *     essential is distributed in the hope that it will be useful,
 *     but WITHOUT ANY WARRANTY; without even the implied warranty of
 *     MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 *     GNU General Public License for more details.
 *
 *     You should have received a copy of the GNU General Public License
 *     along with essential.  If not, see <http://www.gnu.org/licenses/>.
 */

package net.craftforge.essential.supply;

import net.craftforge.essential.supply.exceptions.BadInputException;
import net.craftforge.essential.supply.exceptions.SupplyException;

import java.io.Reader;

/**
 * Deserializes read content to objects.
 *
 * @author Christian Bick
 * @since 02.12.2010
 */
public interface Consumer {

    /**
     * Deserializes the content read by the given reader to an object
     * if the specified class.
     *
     * @param clazz The class
     * @param reader The reader
     * @return The object
     * @throws BadInputException if the input cannot be deserialized
     * @throws SupplyException if the deserialization process failed
     */
    public Object consume(Class<?> clazz, Reader reader) throws BadInputException, SupplyException;
}
