/*
 * This file is part of essential.
 *
 *     essential is free software: you can redistribute it and/or modify
 *     it under the terms of the GNU General Public License as published by
 *     the Free Software Foundation, either version 3 of the License, or
 *     (at your option) any later version.
 *
 *     essential is distributed in the hope that it will be useful,
 *     but WITHOUT ANY WARRANTY; without even the implied warranty of
 *     MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 *     GNU General Public License for more details.
 *
 *     You should have received a copy of the GNU General Public License
 *     along with essential.  If not, see <http://www.gnu.org/licenses/>.
 */

package net.craftforge.essential.supply.suppliers.basic;

import net.craftforge.essential.supply.Producer;
import net.craftforge.essential.supply.Produces;
import net.craftforge.essential.supply.exceptions.SupplyException;

import java.io.IOException;
import java.io.Writer;

/**
 * A basic producer is used to serialize an object to plain text.
 *
 * @author Christian Bick
 * @since 18.11.11
 */
@Produces({"text/plain"})
public class BasicProducer implements Producer{

    /**
     * Serializes the given object to plain text by using the object's toString().
     * Uses the specified writer to write the result.
     *
     * @param object The object
     * @param writer The writer
     */
    public void produce(Object object, Writer writer) throws SupplyException {
        try {
            String text = object.toString();
            writer.write(text);
            writer.close();
        } catch (IOException e) {
            throw new SupplyException(e);
        }
    }
}
