/*
 * This file is part of essential.
 *
 *     essential is free software: you can redistribute it and/or modify
 *     it under the terms of the GNU General Public License as published by
 *     the Free Software Foundation, either version 3 of the License, or
 *     (at your option) any later version.
 *
 *     essential is distributed in the hope that it will be useful,
 *     but WITHOUT ANY WARRANTY; without even the implied warranty of
 *     MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 *     GNU General Public License for more details.
 *
 *     You should have received a copy of the GNU General Public License
 *     along with essential.  If not, see <http://www.gnu.org/licenses/>.
 */

package net.craftforge.essential.supply.suppliers.jackson;

import net.craftforge.commons.configuration.PropertiesHolder;

import java.util.Map;

/**
 * A Jackson configuration provides a fine tuning for the Jackson serialization and
 * deserialization process.
 *
 * @author Christian Bick
 * @since 18.11.11
 */
public class JacksonConfiguration extends PropertiesHolder {

    public static final String PROPERTY_JSON_DESERIALIZATION = "jackson.in";
    public static final String PROPERTY_JSON_SERIALIZATION = "jackson.out";

    /**
     * The default configuration file
     */
    public static final String DEFAULT_CONFIG_FILE = "jackson.properties";

    /**
     * Initializes a configuration using the default configuration file.
     */
    public JacksonConfiguration() {
        this(DEFAULT_CONFIG_FILE);
    }

    /**
     * Initializes a configuration using the given configuration file.
     *
     * @param configFile The configuration file
     */
    public JacksonConfiguration(String configFile) {
        super("/" + configFile);
    }

    /**
     * Gets the JSON deserialization properties. Adding properties according to
     * specifications can be used to fine-tune the JSON deserialization process.
     *
     * @return The JSON deserialization properties as Map
     */
    public Map<String, String> getJsonDeserializationProperties() {
        return getProperties(PROPERTY_JSON_DESERIALIZATION);
    }

    /**
     * Gets the JSON serialization properties. Adding properties according to
     * specifications can be used to fine-tune the JSON serialization process.
     *
     * @return The JSON serialization properties as Map
     */
    public Map<String, String> getJsonSerializationProperties() {
        return getProperties(PROPERTY_JSON_SERIALIZATION);
    }
}
