/*
 * This file is part of essential.
 *
 *     essential is free software: you can redistribute it and/or modify
 *     it under the terms of the GNU General Public License as published by
 *     the Free Software Foundation, either version 3 of the License, or
 *     (at your option) any later version.
 *
 *     essential is distributed in the hope that it will be useful,
 *     but WITHOUT ANY WARRANTY; without even the implied warranty of
 *     MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 *     GNU General Public License for more details.
 *
 *     You should have received a copy of the GNU General Public License
 *     along with essential.  If not, see <http://www.gnu.org/licenses/>.
 */

package net.craftforge.essential.supply.suppliers.jaxb;

import net.craftforge.commons.configuration.PropertiesHolder;

import java.util.Map;

/**
 * A JAXB configuration provides a fine tuning for the JAXB serialization and
 * deserialization process.
 *
 * @author Christian Bick
 * @since 25.10.11
 */
public class JaxbConfiguration extends PropertiesHolder {

    public static final String PROPERTY_XML_DESERIALIZATION = "jaxb.in";
    public static final String PROPERTY_XML_SERIALIZATION = "jaxb.out";

    /**
     * The default configuration file
     */
    public static final String DEFAULT_CONFIG_FILE = "jaxb.properties";

    /**
     * Initializes a configuration using the default configuration file.
     */
    public JaxbConfiguration() {
        this(DEFAULT_CONFIG_FILE);
    }

    /**
     * Initializes a configuration using the given configuration file.
     *
     * @param configFile The configuration file
     */
    public JaxbConfiguration(String configFile) {
        super("/" + configFile);
    }

    /**
     * Gets the XML deserialization properties. Adding properties according to
     * specifications can be used to fine-tune the XML deserialization process.
     *
     * @return The XML deserialization properties as Map
     */
    public Map<String, String> getXmlDeserializationProperties() {
        return getProperties(PROPERTY_XML_DESERIALIZATION);
    }

    /**
     * Gets the XML serialization properties. Adding properties according to
     * specifications can be used to fine-tune the XML serialization process.
     *
     * @return The XML serialization properties as Map
     */
    public Map<String, String> getXmlSerializationProperties() {
        return getProperties(PROPERTY_XML_SERIALIZATION);
    }
}
